# Dies ist ein einfaches Programm für die Projektarbeit.
# Autor: Jan-Erik Engeln

antwort =  input("Wer leitet das Projektstudium in E-Business? Antwort hier: ")

if antwort in ["Martin Hepp", "Prof. Hepp", "Dr. Hepp", "Prof. Dr. Hepp"]:
	print ("Richtig!")

else: 
	print ("Schau lieber nochmal nach!")

input ()







from distutils.core import setup

setup (
	name='Projektarbeit',
	version='0.1',
	author='eryk94',
	packages=['projektarbeit'],
	scripts=['bin/project.py'],
	license='Creative Commons Attribution-Noncommercial-Share Alike license',
	description='Example for How-to create a package'
)
